@@ -1,9 +1,9 @@
 ;;; no-littering.el --- help keeping ~/.emacs.d clean
 
-;; Copyright (C) 2016-2017  Jonas Bernoulli
+;; Copyright (C) 2016-2018  Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <jonas@bernoul.li>
-;; Homepage: https://github.com/tarsius/no-littering
+;; Homepage: https://github.com/emacscollective/no-littering
 ;; Package-Requires: ((cl-lib "0.5"))
 
 ;; This file is not part of GNU Emacs.
@@ -44,7 +44,8 @@
 ;; We still have a long way to go until most built-in and many third-
 ;; party path variables are properly "themed".  Like a color-theme,
 ;; this package depends on user contributions to accomplish decent
-;; coverage.  Pull requests are highly welcome.
+;; coverage.  Pull requests are highly welcome (but please follow the
+;; conventions described below and in the pull request template).
 
 ;; Usage:
 
@@ -66,7 +67,7 @@
 
 ;; Conventions:
 
-;; * File names
+;; * A) File names
 ;;
 ;; 1. File names are based on the name of the respective Emacs Lisp
 ;;    variables and the name of the respective Emacs package.
@@ -88,7 +89,7 @@
 ;;    E.g.  if a file contains an S-expression, then the suffix should be
 ;;    `*.el`.
 
-;; * File location and subdirectories
+;; * B) File location and subdirectories
 ;;
 ;; 1. If a package has only one data file, then that is usually placed in
 ;;    `no-littering-var-directory` itself.  Likewise if a package has
@@ -104,7 +105,7 @@
 ;;    the package in most cases.  The subdirectory name may serve as the
 ;;    package prefix of the file name.
 ;;
-;; 4. A package that provides a "framework" for other packages to use,
+;; 4. If a package provides a "framework" for other packages to use,
 ;;    then we may reuse its directories for other packages that make use
 ;;    of that framework or otherwise "extend" the "main package".
 ;;    E.g. we place all `helm` related files in `helm/`.
@@ -121,7 +122,7 @@
 ;;    when the name of the variable is `<package>-directory`, in which
 ;;    case we would use just `<package>/` as the path.
 
-;; * Ordering and alignment
+;; * C) Ordering and alignment
 ;;
 ;; 1. The code that sets the values of themed variables is split into two
 ;;    groups.  The first group sets the value of variables that belong to
@@ -137,7 +138,7 @@
 ;;    If it turns out that this happens very often, then we will adjust
 ;;    the alignment eventually.
 
-;; * Commit messages
+;; * D) Commit messages
 ;;
 ;; 1. Please theme each package using a separate commit and use commit
 ;;    messages of the form "<package>: theme <variable".
@@ -148,10 +149,22 @@
 ;; 3. If the variable names do not fit nicely on the summary line, then
 ;;    use a message such as:
 ;;
-;;   foo: theme variables
+;;      foo: theme variables
 ;;
-;;   Theme `foo-config-file', `foo-cache-directory',
-;;   and `foo-persistent-file'.
+;;      Theme `foo-config-file', `foo-cache-directory',
+;;      and `foo-persistent-file'.
+;; 4. When appropriate add statements like the following to the commit
+;;    message:
+;;
+;;    - This file is used to store an s-expression.
+;;    - This file is used to store raw text.
+;;    - This is the only configuration/data file of the package.
+;;    - This package does/doesn't take care of creating the containing
+;;      directory if necessary. (If the package does not do it, then you
+;;      should also fix that and submit an upstream pull request.)
+;;
+;; 5. If you are uncertain, then be explicit about it by adding a comment
+;;    to the pull-request.
 
 ;;; Code:
 
@@ -192,7 +205,9 @@ This variable has to be set before `no-littering' is loaded.")
     (setq bookmark-default-file            (var "bookmark-default.el"))
     (eval-after-load 'desktop
       `(make-directory ,(var "desktop/") t))
-    (setq desktop-path                     (list (var "desktop/")))
+    (setq desktop-dirname                  (var "desktop/"))
+    (setq desktop-path                     (list desktop-dirname))
+    (setq diary-file                       (var "diary"))
     (setq epkg-repository                  (var "epkgs/"))
     (setq eshell-directory-name            (var "eshell/"))
     (eval-after-load 'eww
@@ -205,6 +220,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq image-dired-gallery-dir          (var "image-dired/gallery/"))
     (setq image-dired-temp-image-file      (var "image-dired/temp-image"))
     (setq image-dired-temp-rotate-image-file (var "image-dired/temp-rotate-image"))
+    (setq kkc-init-file-name               (var "kkc-init.el"))
     (eval-after-load 'newsticker
       `(make-directory ,(var "newsticker/") t))
     (setq newsticker-cache-filename        (var "newsticker/cache.el"))
@@ -212,11 +228,14 @@ This variable has to be set before `no-littering' is loaded.")
     (setq nsm-settings-file                (var "nsm-settings.el"))
     (eval-after-load 'org
       `(make-directory ,(var "org/") t))
+    (setq omnisharp-cache-directory        (var "omnisharp/cache"))
     (setq org-clock-persist-file           (var "org/clock-persist.el"))
     (setq org-id-locations-file            (var "org/id-locations.el"))
     (setq org-publish-timestamp-directory  (var "org/timestamps/"))
     (setq org-registry-file                (var "org/registry.el"))
     (setq recentf-save-file                (var "recentf-save.el"))
+    (setq remember-data-file               (var "remember/data"))
+    (setq remember-data-directory          (var "remember/data.d/"))
     (setq save-place-file                  (var "save-place.el"))
     (setq savehist-file                    (var "savehist.el"))
     (setq semanticdb-default-save-directory (var "semantic/"))
@@ -229,7 +248,9 @@ This variable has to be set before `no-littering' is loaded.")
 ;;; Third-party packages
 
     (setq ac-comphist-file                 (var "ac-comphist.el"))
-    (setq anaconda-mode-installation-directory (etc "anaconda-mode/"))
+    (setq amx-save-file                    (var "amx-save.el"))
+    (setq anaconda-mode-installation-directory (var "anaconda-mode/"))
+    (setq async-byte-compile-log-file      (var "async-bytecomp.log"))
     (eval-after-load 'bbdb
       `(make-directory ,(var "bbdb/") t))
     (setq bbdb-file                        (var "bbdb/bbdb.el"))
@@ -242,8 +263,9 @@ This variable has to be set before `no-littering' is loaded.")
     (eval-after-load 'company-statistics
       `(make-directory ,(var "company/") t))
     (setq company-statistics-file          (var "company/statistics.el"))
+    (setq elbank-data-file                 (var "elbank-data.el"))
     (eval-after-load 'elfeed
-       `(make-directory ,(var "elfeed/") t))
+      `(make-directory ,(var "elfeed/") t))
     (setq elfeed-db-directory              (var "elfeed/db/"))
     (setq elfeed-enclosure-default-dir     (var "elfeed/enclosures/"))
     (eval-after-load 'x-win
@@ -259,12 +281,18 @@ directories."
     (eval-after-load 'emojify
       `(make-directory ,(var "emojify/") t))
     (setq emojify-emojis-dir               (var "emojify/"))
+    (setq geben-temporary-file-directory   (var "geben/"))
+    (eval-after-load 'geiser
+      `(make-directory ,(var "geiser/") t))
+    (setq geiser-repl-history-filename     (var "geiser/repl-history"))
     (eval-after-load 'helm
       `(make-directory ,(var "helm/") t))
     (setq helm-adaptive-history-file       (var "helm/adaptive-history.el"))
+    (setq helm-backup-path                 (var "helm/backup/"))
     (setq helm-github-stars-cache-file     (var "helm/github-stars-cache.el"))
     (setq historian-save-file              (var "historian-save.el"))
     (setq indium-workspace-file            (var "indium/workspaces.el"))
+    (setq irfc-directory                   (var "irfc/"))
     (setq irony-user-dir                   (var "irony/"))
     (setq jabber-avatar-cache-directory    (var "jabber/avatar-cache"))
     (eval-after-load 'jabber
@@ -272,10 +300,21 @@ directories."
     (setq jabber-history-dir               (var "jabber/history"))
     (eval-after-load 'jabber
       `(make-directory ,(var "jabber/history/") t))
+    (setq keyfreq-file                     (var "keyfreq.el"))
+    (setq keyfreq-file-lock                (var "keyfreq.lock"))
+    (eval-after-load 'lookup
+      `(make-directory ,(etc "lookup/") t))
+    (setq litable-list-file                (var "litable-list.el"))
+    (setq lookup-init-directory            (etc "lookup/"))
     (setq magithub-dir                     (var "magithub/"))
     (setq magithub-cache-file              (var "magithub/cache.el"))
     (setq mc/list-file                     (var "mc-list.el"))
+    (setq meghanada-server-install-dir     (var "meghanada/"))
     (setq multi-compile-history-file       (var "multi-compile-history.el"))
+    ;; The value of this variable MUST NOT end with ".el" but the
+    ;; actual file name MUST end with ".el".  Use "git blame" for
+    ;; more information.
+    (setq notmuch-init-file                (etc "notmuch-init"))
     (setq org-gcal-dir                     (var "org/gcal/"))
     (eval-after-load 'org-caldav
       `(make-directory ,(var "org/caldav/save") t))
@@ -288,6 +327,8 @@ directories."
       `(make-directory ,(var "projectile/") t))
     (setq projectile-cache-file            (var "projectile/cache.el"))
     (setq projectile-known-projects-file   (var "projectile/known-projects.el"))
+    (setq pyim-dcache-directory            (var "pyim/dcache/"))
+    (setq quack-dir                        (var "quack/"))
     (setq request-storage-directory        (var "request/storage/"))
     (setq rmh-elfeed-org-files             (list (var "elfeed/rmh-elfeed.org")))
     (setq runner-init-file                 (var "runner-init.el"))
@@ -301,6 +342,7 @@ directories."
     (setq tldr-directory-path              (var "tldr/"))
     (setq undo-tree-history-directory-alist (list (cons "." (var "undo-tree-hist/"))))
     (setq user-emacs-ensime-directory      (var "ensime/"))
+    (setq vimish-fold-dir                  (var "vimish-fold/"))
     (eval-after-load 'xkcd
       `(make-directory ,(var "xkcd/") t))
     (setq xkcd-cache-dir                   (var "xkcd/"))
